%% 
%% Minimal class file defining the style for abstracts submitted to
%% EACS2022 conference, based on SolMech/ICMM files.
%%
%% Author: Toby D. Young (2018)
%% Support: ptauzow@ippt.pan.pl
%%

%% 
%% Demand this version of LaTeX kernel (want/need error handling):
%%
\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{eacs2022}[2019/12/04 v2.1a (Toby D. Young et al.)]

\setlength{\textwidth}{6.5in}
\setlength{\textheight}{8in}

%%
%% Set up the page. Use a4paper; otherwise hijack the basics from
%% LaTeX2e's own article file to make life easier   ;-)
%%
\def\@@ptsize{11pt}
\DeclareOption{11pt}{\def\@@ptsize{11pt}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[a4paper,oneside,onecolumn,final,\@@ptsize]{article}
%\PassOptionsToClass{a4paper,onecolumn}{article}
%\LoadClassWithOptions{article} 

%%
%% "Must have" packages
%%
\RequirePackage[T1]{fontenc}
\RequirePackage[english]{babel}
\RequirePackage[top=30mm,bottom=20mm,left=20mm,right=20mm]{geometry}
\RequirePackage{times}
\RequirePackage{titlesec}
\RequirePackage{authblk}
\PassOptionsToClass{blocks}{authblk}
\RequirePackage{cite}
\PassOptionsToClass{sort}{cite}

\gdef\Defaultx@fontfamily{Times-Roman}
%%
%% Misc. packages
%%
\RequirePackage[leqno]{amsmath}
\RequirePackage{setspace}

%%
%% Process options:
%%
\ProcessOptions\relax

%%
%% Other options:
%%
%\normalsfcodes
\singlespacing
%\onehalfspacing
%\doublespacing

\renewcommand*{\Authfont}{\normalfont\large}
\renewcommand*{\Affilfont}{\normalfont\small\itshape}
\newcommand*{\@contact}{}
\newcommand*{\contact}[1]{\renewcommand*{\@contact}{#1}}

\setlength{\parindent}{0pt}
\setlength{\parskip}{5pt}
\setlength{\affilsep}{5pt}

%%
%% Redefine section headers; essentially by making them all
%% indistiguishable and thus worthless. Still need section for the
%% bibliography though...
%%
\titleformat{\section}{\large\bfseries\raggedright}{\thesection\,.}{5pt}{}
\titleformat{\subsection}{\large\bfseries\raggedright}{\thesubsection\,.}{5pt}{}
\titleformat{\subsubsection}{\large\bfseries\raggedright}{\thesubsubsection\,.}{5pt}{}
\let\bibsection\relax

\pagestyle{empty}

%% 
%% The following defines how the title, author, and affiliation
%% appears:
%% 
\renewcommand{\maketitle}{
  \begingroup\center
  {\textbf{\Large\@title}\par}
  \par\@author\par
  e-mail:\,\@contact
  \endcenter\endgroup
}

%% 
%% The following defines how the acknowledgment will look like:
%% 
\def\acknowledgment{\par\small
  \@startsection{subsection}{}{\z@}{8pt}{0pt}{\bfseries}*{Acknowledgments\,\,\,}%
}
\settowidth{\labelwidth}{99.}%
\leftmargin\labelwidth
\advance\leftmargin\labelsep\topsep \z@ \parsep 0pt plus .1pt
\def\newblock{\hskip .11em plus .33em minus .07em}
\sloppy
\widowpenalty=4500
\clubpenalty=4500
\sfcode`\.=1000\relax
\let\endacknowledgment

%% 
%% Redefine the way the bibliography looks:
%% 
\def\thebibliography#1{\par\small
  \@startsection{subsection}{}{\z@}{8pt}{5pt}{\bfseries}*{References}%
  \list{[\arabic{enumi}]}{%
    \settowidth{\labelwidth}{99.}%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep\topsep \z@ \parsep 0pt plus .1pt
    \itemsep \parsep 
    \usecounter{enumi}}%
  \def\newblock{\hskip .11em plus .33em minus .07em}
  \sloppy
  \widowpenalty=4500
  \clubpenalty=4500
  \sfcode`\.=1000\relax}
\let\endthebibliography=\endlist

%%
%% Tell LaTeX to stop reading this file.
%%
\endinput



